# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core_types.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'core_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ore_types.proto\x12\x0bproto_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x99\x02\n\rCoreEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x05\x65xtra\x18\t \x03(\x0b\x32%.proto_types.CoreEventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x0cNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\x91\x02\n\x08NodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\rnode_relation\x18\n \x01(\x0b\x32\x19.proto_types.NodeRelation\"\x7f\n\rTimingInfoMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd1\x01\n\x0cRunResultMsg\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x0btiming_info\x18\x03 \x03(\x0b\x32\x1a.proto_types.TimingInfoMsg\x12\x0e\n\x06thread\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x31\n\x10\x61\x64\x61pter_response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"\\\n\nColumnType\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14previous_column_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrent_column_type\x18\x03 \x01(\t\"Y\n\x10\x43olumnConstraint\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x03 \x01(\t\"T\n\x0fModelConstraint\x12\x17\n\x0f\x63onstraint_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\"9\n\x11MainReportVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0blog_version\x18\x02 \x01(\x05\"n\n\x14MainReportVersionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.MainReportVersion\"r\n\x0eMainReportArgs\x12\x33\n\x04\x61rgs\x18\x01 \x03(\x0b\x32%.proto_types.MainReportArgs.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x11MainReportArgsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainReportArgs\"+\n\x15MainTrackingUserState\x12\x12\n\nuser_state\x18\x01 \x01(\t\"v\n\x18MainTrackingUserStateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainTrackingUserState\"5\n\x0fMergedFromState\x12\x12\n\nnum_merged\x18\x01 \x01(\x05\x12\x0e\n\x06sample\x18\x02 \x03(\t\"j\n\x12MergedFromStateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.MergedFromState\"A\n\x14MissingProfileTarget\x12\x14\n\x0cprofile_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\"t\n\x17MissingProfileTargetMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MissingProfileTarget\"(\n\x11InvalidOptionYAML\x12\x13\n\x0boption_name\x18\x01 \x01(\t\"n\n\x14InvalidOptionYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.InvalidOptionYAML\"!\n\x12LogDbtProjectError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x15LogDbtProjectErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProjectError\"3\n\x12LogDbtProfileError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08profiles\x18\x02 \x03(\t\"p\n\x15LogDbtProfileErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProfileError\"!\n\x12StarterProjectPath\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"p\n\x15StarterProjectPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StarterProjectPath\"$\n\x15\x43onfigFolderDirectory\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"v\n\x18\x43onfigFolderDirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConfigFolderDirectory\"\'\n\x14NoSampleProfileFound\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\"t\n\x17NoSampleProfileFoundMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NoSampleProfileFound\"6\n\x18ProfileWrittenWithSample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"|\n\x1bProfileWrittenWithSampleMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProfileWrittenWithSample\"B\n$ProfileWrittenWithTargetTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x94\x01\n\'ProfileWrittenWithTargetTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.ProfileWrittenWithTargetTemplateYAML\"C\n%ProfileWrittenWithProjectTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x96\x01\n(ProfileWrittenWithProjectTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.ProfileWrittenWithProjectTemplateYAML\"\x12\n\x10SettingUpProfile\"l\n\x13SettingUpProfileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SettingUpProfile\"\x1c\n\x1aInvalidProfileTemplateYAML\"\x80\x01\n\x1dInvalidProfileTemplateYAMLMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.InvalidProfileTemplateYAML\"(\n\x18ProjectNameAlreadyExists\x12\x0c\n\x04name\x18\x01 \x01(\t\"|\n\x1bProjectNameAlreadyExistsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProjectNameAlreadyExists\"K\n\x0eProjectCreated\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x02 \x01(\t\x12\x11\n\tslack_url\x18\x03 \x01(\t\"h\n\x11ProjectCreatedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ProjectCreated\"@\n\x1aPackageRedirectDeprecation\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x80\x01\n\x1dPackageRedirectDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.PackageRedirectDeprecation\"\x1f\n\x1dPackageInstallPathDeprecation\"\x86\x01\n PackageInstallPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.PackageInstallPathDeprecation\"H\n\x1b\x43onfigSourcePathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"\x82\x01\n\x1e\x43onfigSourcePathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigSourcePathDeprecation\"F\n\x19\x43onfigDataPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"~\n\x1c\x43onfigDataPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConfigDataPathDeprecation\".\n\x17MetricAttributesRenamed\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"z\n\x1aMetricAttributesRenamedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.MetricAttributesRenamed\"+\n\x17\x45xposureNameDeprecation\x12\x10\n\x08\x65xposure\x18\x01 \x01(\t\"z\n\x1a\x45xposureNameDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.ExposureNameDeprecation\"^\n\x13InternalDeprecation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x18\n\x10suggested_action\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"r\n\x16InternalDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.InternalDeprecation\"@\n\x1a\x45nvironmentVariableRenamed\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x80\x01\n\x1d\x45nvironmentVariableRenamedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.EnvironmentVariableRenamed\"3\n\x18\x43onfigLogPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"|\n\x1b\x43onfigLogPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ConfigLogPathDeprecation\"6\n\x1b\x43onfigTargetPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"\x82\x01\n\x1e\x43onfigTargetPathDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigTargetPathDeprecation\"C\n\x16TestsConfigDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"x\n\x19TestsConfigDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.TestsConfigDeprecation\"\x1e\n\x1cProjectFlagsMovedDeprecation\"\x84\x01\n\x1fProjectFlagsMovedDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.ProjectFlagsMovedDeprecation\"C\n\x1fSpacesInResourceNameDeprecation\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\"\x8a\x01\n\"SpacesInResourceNameDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SpacesInResourceNameDeprecation\"i\n\"ResourceNamesWithSpacesDeprecation\x12\x1b\n\x13\x63ount_invalid_names\x18\x01 \x01(\x05\x12\x17\n\x0fshow_debug_hint\x18\x02 \x01(\x08\x12\r\n\x05level\x18\x03 \x01(\t\"\x90\x01\n%ResourceNamesWithSpacesDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.proto_types.ResourceNamesWithSpacesDeprecation\"_\n)PackageMaterializationOverrideDeprecation\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x1c\n\x14materialization_name\x18\x02 \x01(\t\"\x9e\x01\n,PackageMaterializationOverrideDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.proto_types.PackageMaterializationOverrideDeprecation\"#\n!SourceFreshnessProjectHooksNotRun\"\x8e\x01\n$SourceFreshnessProjectHooksNotRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.SourceFreshnessProjectHooksNotRun\"0\n.MFTimespineWithoutYamlConfigurationDeprecation\"\xa8\x01\n1MFTimespineWithoutYamlConfigurationDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.proto_types.MFTimespineWithoutYamlConfigurationDeprecation\"#\n!MFCumulativeTypeParamsDeprecation\"\x8e\x01\n$MFCumulativeTypeParamsDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.MFCumulativeTypeParamsDeprecation\",\n*MicrobatchMacroOutsideOfBatchesDeprecation\"\xa0\x01\n-MicrobatchMacroOutsideOfBatchesDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.proto_types.MicrobatchMacroOutsideOfBatchesDeprecation\"V\n\x0f\x44\x65precatedModel\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65precation_date\x18\x03 \x01(\t\"j\n\x12\x44\x65precatedModelMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DeprecatedModel\"7\n\x12InputFileDiffError\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"p\n\x15InputFileDiffErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InputFileDiffError\"?\n\x14InvalidValueForField\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\t\"t\n\x17InvalidValueForFieldMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.InvalidValueForField\"Q\n\x11ValidationWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\"n\n\x14ValidationWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ValidationWarning\"!\n\x11ParsePerfInfoPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"n\n\x14ParsePerfInfoPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ParsePerfInfoPath\"1\n!PartialParsingErrorProcessingFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\x8e\x01\n$PartialParsingErrorProcessingFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.PartialParsingErrorProcessingFile\"\x86\x01\n\x13PartialParsingError\x12?\n\x08\x65xc_info\x18\x01 \x03(\x0b\x32-.proto_types.PartialParsingError.ExcInfoEntry\x1a.\n\x0c\x45xcInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x16PartialParsingErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.PartialParsingError\"\x1b\n\x19PartialParsingSkipParsing\"~\n\x1cPartialParsingSkipParsingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.PartialParsingSkipParsing\"&\n\x14UnableToPartialParse\x12\x0e\n\x06reason\x18\x01 \x01(\t\"t\n\x17UnableToPartialParseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.UnableToPartialParse\"f\n\x12StateCheckVarsHash\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x0c\n\x04vars\x18\x02 \x01(\t\x12\x0f\n\x07profile\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"p\n\x15StateCheckVarsHashMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StateCheckVarsHash\"\x1a\n\x18PartialParsingNotEnabled\"|\n\x1bPartialParsingNotEnabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.PartialParsingNotEnabled\"C\n\x14ParsedFileLoadFailed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"t\n\x17ParsedFileLoadFailedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParsedFileLoadFailed\"H\n\x15PartialParsingEnabled\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x05\x12\r\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hanged\x18\x03 \x01(\x05\"v\n\x18PartialParsingEnabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.PartialParsingEnabled\"8\n\x12PartialParsingFile\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\"p\n\x15PartialParsingFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.PartialParsingFile\"\xaf\x01\n\x1fInvalidDisabledTargetInTestNode\x12\x1b\n\x13resource_type_title\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1a\n\x12original_file_path\x18\x03 \x01(\t\x12\x13\n\x0btarget_kind\x18\x04 \x01(\t\x12\x13\n\x0btarget_name\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\"\x8a\x01\n\"InvalidDisabledTargetInTestNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.InvalidDisabledTargetInTestNode\"7\n\x18UnusedResourceConfigPath\x12\x1b\n\x13unused_config_paths\x18\x01 \x03(\t\"|\n\x1bUnusedResourceConfigPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.UnusedResourceConfigPath\"3\n\rSeedIncreased\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x10SeedIncreasedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.SeedIncreased\">\n\x18SeedExceedsLimitSamePath\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x1bSeedExceedsLimitSamePathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.SeedExceedsLimitSamePath\"D\n\x1eSeedExceedsLimitAndPathChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n!SeedExceedsLimitAndPathChangedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.SeedExceedsLimitAndPathChanged\"\\\n\x1fSeedExceedsLimitChecksumChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rchecksum_name\x18\x03 \x01(\t\"\x8a\x01\n\"SeedExceedsLimitChecksumChangedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SeedExceedsLimitChecksumChanged\"%\n\x0cUnusedTables\x12\x15\n\runused_tables\x18\x01 \x03(\t\"d\n\x0fUnusedTablesMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.UnusedTables\"\x87\x01\n\x17WrongResourceSchemaFile\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x1c\n\x14plural_resource_type\x18\x03 \x01(\t\x12\x10\n\x08yaml_key\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\"z\n\x1aWrongResourceSchemaFileMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.WrongResourceSchemaFile\"K\n\x10NoNodeForYamlKey\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x10\n\x08yaml_key\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"l\n\x13NoNodeForYamlKeyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.NoNodeForYamlKey\"+\n\x15MacroNotFoundForPatch\x12\x12\n\npatch_name\x18\x01 \x01(\t\"v\n\x18MacroNotFoundForPatchMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MacroNotFoundForPatch\"\xb8\x01\n\x16NodeNotFoundOrDisabled\x12\x1a\n\x12original_file_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_type_title\x18\x03 \x01(\t\x12\x13\n\x0btarget_name\x18\x04 \x01(\t\x12\x13\n\x0btarget_kind\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\x12\x10\n\x08\x64isabled\x18\x07 \x01(\t\"x\n\x19NodeNotFoundOrDisabledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.NodeNotFoundOrDisabled\"H\n\x0fJinjaLogWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"j\n\x12JinjaLogWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.JinjaLogWarning\"E\n\x0cJinjaLogInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"d\n\x0fJinjaLogInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.JinjaLogInfo\"F\n\rJinjaLogDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"f\n\x10JinjaLogDebugMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.JinjaLogDebug\"\xae\x01\n\x1eUnpinnedRefNewVersionAvailable\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rref_node_name\x18\x02 \x01(\t\x12\x18\n\x10ref_node_package\x18\x03 \x01(\t\x12\x18\n\x10ref_node_version\x18\x04 \x01(\t\x12\x17\n\x0fref_max_version\x18\x05 \x01(\t\"\x88\x01\n!UnpinnedRefNewVersionAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.UnpinnedRefNewVersionAvailable\"\xc6\x01\n\x1cUpcomingReferenceDeprecation\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\x84\x01\n\x1fUpcomingReferenceDeprecationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.UpcomingReferenceDeprecation\"\xbd\x01\n\x13\x44\x65precatedReference\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"r\n\x16\x44\x65precatedReferenceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DeprecatedReference\"<\n$UnsupportedConstraintMaterialization\x12\x14\n\x0cmaterialized\x18\x01 \x01(\t\"\x94\x01\n\'UnsupportedConstraintMaterializationMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.UnsupportedConstraintMaterialization\"M\n\x14ParseInlineNodeError\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\"t\n\x17ParseInlineNodeErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParseInlineNodeError\"(\n\x19SemanticValidationFailure\x12\x0b\n\x03msg\x18\x02 \x01(\t\"~\n\x1cSemanticValidationFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.SemanticValidationFailure\"\x8a\x03\n\x19UnversionedBreakingChange\x12\x18\n\x10\x62reaking_changes\x18\x01 \x03(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x17\n\x0fmodel_file_path\x18\x03 \x01(\t\x12\"\n\x1a\x63ontract_enforced_disabled\x18\x04 \x01(\x08\x12\x17\n\x0f\x63olumns_removed\x18\x05 \x03(\t\x12\x34\n\x13\x63olumn_type_changes\x18\x06 \x03(\x0b\x32\x17.proto_types.ColumnType\x12I\n\"enforced_column_constraint_removed\x18\x07 \x03(\x0b\x32\x1d.proto_types.ColumnConstraint\x12G\n!enforced_model_constraint_removed\x18\x08 \x03(\x0b\x32\x1c.proto_types.ModelConstraint\x12\x1f\n\x17materialization_changed\x18\t \x03(\t\"~\n\x1cUnversionedBreakingChangeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.UnversionedBreakingChange\"*\n\x14WarnStateTargetEqual\x12\x12\n\nstate_path\x18\x01 \x01(\t\"t\n\x17WarnStateTargetEqualMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.WarnStateTargetEqual\"%\n\x16\x46reshnessConfigProblem\x12\x0b\n\x03msg\x18\x01 \x01(\t\"x\n\x19\x46reshnessConfigProblemMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessConfigProblem\"6\n MicrobatchModelNoEventTimeInputs\x12\x12\n\nmodel_name\x18\x01 \x01(\t\"\x8c\x01\n#MicrobatchModelNoEventTimeInputsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.proto_types.MicrobatchModelNoEventTimeInputs\"J\n\x1eInvalidConcurrentBatchesConfig\x12\x12\n\nnum_models\x18\x01 \x01(\x05\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x02 \x01(\t\"\x88\x01\n!InvalidConcurrentBatchesConfigMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.InvalidConcurrentBatchesConfig\"/\n\x1dGitSparseCheckoutSubdirectory\x12\x0e\n\x06subdir\x18\x01 \x01(\t\"\x86\x01\n GitSparseCheckoutSubdirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.GitSparseCheckoutSubdirectory\"/\n\x1bGitProgressCheckoutRevision\x12\x10\n\x08revision\x18\x01 \x01(\t\"\x82\x01\n\x1eGitProgressCheckoutRevisionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.GitProgressCheckoutRevision\"4\n%GitProgressUpdatingExistingDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x96\x01\n(GitProgressUpdatingExistingDependencyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.GitProgressUpdatingExistingDependency\".\n\x1fGitProgressPullingNewDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x8a\x01\n\"GitProgressPullingNewDependencyMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressPullingNewDependency\"\x1d\n\x0eGitNothingToDo\x12\x0b\n\x03sha\x18\x01 \x01(\t\"h\n\x11GitNothingToDoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.GitNothingToDo\"E\n\x1fGitProgressUpdatedCheckoutRange\x12\x11\n\tstart_sha\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_sha\x18\x02 \x01(\t\"\x8a\x01\n\"GitProgressUpdatedCheckoutRangeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressUpdatedCheckoutRange\"*\n\x17GitProgressCheckedOutAt\x12\x0f\n\x07\x65nd_sha\x18\x01 \x01(\t\"z\n\x1aGitProgressCheckedOutAtMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.GitProgressCheckedOutAt\")\n\x1aRegistryProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x80\x01\n\x1dRegistryProgressGETRequestMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.RegistryProgressGETRequest\"=\n\x1bRegistryProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x82\x01\n\x1eRegistryProgressGETResponseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RegistryProgressGETResponse\"_\n\x1dSelectorReportInvalidSelector\x12\x17\n\x0fvalid_selectors\x18\x01 \x01(\t\x12\x13\n\x0bspec_method\x18\x02 \x01(\t\x12\x10\n\x08raw_spec\x18\x03 \x01(\t\"\x86\x01\n SelectorReportInvalidSelectorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.SelectorReportInvalidSelector\"\x15\n\x13\x44\x65psNoPackagesFound\"r\n\x16\x44\x65psNoPackagesFoundMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsNoPackagesFound\"/\n\x17\x44\x65psStartPackageInstall\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"z\n\x1a\x44\x65psStartPackageInstallMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsStartPackageInstall\"\'\n\x0f\x44\x65psInstallInfo\x12\x14\n\x0cversion_name\x18\x01 \x01(\t\"j\n\x12\x44\x65psInstallInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DepsInstallInfo\"-\n\x13\x44\x65psUpdateAvailable\x12\x16\n\x0eversion_latest\x18\x01 \x01(\t\"r\n\x16\x44\x65psUpdateAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsUpdateAvailable\"\x0e\n\x0c\x44\x65psUpToDate\"d\n\x0f\x44\x65psUpToDateMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUpToDate\",\n\x14\x44\x65psListSubdirectory\x12\x14\n\x0csubdirectory\x18\x01 \x01(\t\"t\n\x17\x44\x65psListSubdirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.DepsListSubdirectory\".\n\x1a\x44\x65psNotifyUpdatesAvailable\x12\x10\n\x08packages\x18\x01 \x03(\t\"\x80\x01\n\x1d\x44\x65psNotifyUpdatesAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.DepsNotifyUpdatesAvailable\".\n\x1fRegistryIndexProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8a\x01\n\"RegistryIndexProgressGETRequestMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryIndexProgressGETRequest\"B\n RegistryIndexProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x8c\x01\n#RegistryIndexProgressGETResponseMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.proto_types.RegistryIndexProgressGETResponse\"2\n\x1eRegistryResponseUnexpectedType\x12\x10\n\x08response\x18\x01 \x01(\t\"\x88\x01\n!RegistryResponseUnexpectedTypeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseUnexpectedType\"2\n\x1eRegistryResponseMissingTopKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x88\x01\n!RegistryResponseMissingTopKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseMissingTopKeys\"5\n!RegistryResponseMissingNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8e\x01\n$RegistryResponseMissingNestedKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.RegistryResponseMissingNestedKeys\"3\n\x1fRegistryResponseExtraNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8a\x01\n\"RegistryResponseExtraNestedKeysMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryResponseExtraNestedKeys\"(\n\x18\x44\x65psSetDownloadDirectory\x12\x0c\n\x04path\x18\x01 \x01(\t\"|\n\x1b\x44\x65psSetDownloadDirectoryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsSetDownloadDirectory\"-\n\x0c\x44\x65psUnpinned\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x0b\n\x03git\x18\x02 \x01(\t\"d\n\x0f\x44\x65psUnpinnedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUnpinned\"/\n\x1bNoNodesForSelectionCriteria\x12\x10\n\x08spec_raw\x18\x01 \x01(\t\"\x82\x01\n\x1eNoNodesForSelectionCriteriaMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.NoNodesForSelectionCriteria\")\n\x10\x44\x65psLockUpdating\x12\x15\n\rlock_filepath\x18\x01 \x01(\t\"l\n\x13\x44\x65psLockUpdatingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.DepsLockUpdating\"R\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x11packages_filepath\x18\x03 \x01(\t\"h\n\x11\x44\x65psAddPackageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DepsAddPackage\"\xa7\x01\n\x19\x44\x65psFoundDuplicatePackage\x12S\n\x0fremoved_package\x18\x01 \x03(\x0b\x32:.proto_types.DepsFoundDuplicatePackage.RemovedPackageEntry\x1a\x35\n\x13RemovedPackageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1c\x44\x65psFoundDuplicatePackageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.DepsFoundDuplicatePackage\"$\n\x12\x44\x65psVersionMissing\x12\x0e\n\x06source\x18\x01 \x01(\t\"p\n\x15\x44\x65psVersionMissingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.DepsVersionMissing\"/\n\x17\x44\x65psScrubbedPackageName\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"z\n\x1a\x44\x65psScrubbedPackageNameMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsScrubbedPackageName\"?\n\x0f\x41rtifactWritten\x12\x15\n\rartifact_type\x18\x01 \x01(\t\x12\x15\n\rartifact_path\x18\x02 \x01(\t\"j\n\x12\x41rtifactWrittenMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ArtifactWritten\"*\n\x1bRunningOperationCaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x82\x01\n\x1eRunningOperationCaughtErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RunningOperationCaughtError\"\x11\n\x0f\x43ompileComplete\"j\n\x12\x43ompileCompleteMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.CompileComplete\"\x18\n\x16\x46reshnessCheckComplete\"x\n\x19\x46reshnessCheckCompleteMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessCheckComplete\"\x1c\n\nSeedHeader\x12\x0e\n\x06header\x18\x01 \x01(\t\"`\n\rSeedHeaderMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SeedHeader\"]\n\x12SQLRunnerException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"p\n\x15SQLRunnerExceptionMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SQLRunnerException\"\x87\x01\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cpackage_name\x18\x03 \x01(\t\x12,\n\x05owner\x18\x07 \x03(\x0b\x32\x1d.proto_types.Group.OwnerEntry\x1a,\n\nOwnerEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x01\n\rLogTestResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\x12\n\nnum_models\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\x12!\n\x05group\x18\x08 \x01(\x0b\x32\x12.proto_types.Group\x12\x15\n\rattached_node\x18\t \x01(\t\"f\n\x10LogTestResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogTestResult\"k\n\x0cLogStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"d\n\x0fLogStartLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.LogStartLine\"\xb8\x01\n\x0eLogModelResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12!\n\x05group\x18\x07 \x01(\x0b\x32\x12.proto_types.Group\"h\n\x11LogModelResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogModelResult\"\x92\x02\n\x11LogSnapshotResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x34\n\x03\x63\x66g\x18\x07 \x03(\x0b\x32\'.proto_types.LogSnapshotResult.CfgEntry\x12\x16\n\x0eresult_message\x18\x08 \x01(\t\x1a*\n\x08\x43\x66gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x14LogSnapshotResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogSnapshotResult\"\xb9\x01\n\rLogSeedResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0eresult_message\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0e\n\x06schema\x18\x07 \x01(\t\x12\x10\n\x08relation\x18\x08 \x01(\t\"f\n\x10LogSeedResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogSeedResult\"\xad\x01\n\x12LogFreshnessResult\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x13\n\x0bsource_name\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\"p\n\x15LogFreshnessResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogFreshnessResult\"\x98\x01\n\x11LogNodeNoOpResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"n\n\x14LogNodeNoOpResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogNodeNoOpResult\"\"\n\rLogCancelLine\x12\x11\n\tconn_name\x18\x01 \x01(\t\"f\n\x10LogCancelLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogCancelLine\"\x1f\n\x0f\x44\x65\x66\x61ultSelector\x12\x0c\n\x04name\x18\x01 \x01(\t\"j\n\x12\x44\x65\x66\x61ultSelectorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DefaultSelector\"5\n\tNodeStart\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"^\n\x0cNodeStartMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.NodeStart\"g\n\x0cNodeFinished\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12-\n\nrun_result\x18\x02 \x01(\x0b\x32\x19.proto_types.RunResultMsg\"d\n\x0fNodeFinishedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.NodeFinished\"+\n\x1bQueryCancelationUnsupported\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x82\x01\n\x1eQueryCancelationUnsupportedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.QueryCancelationUnsupported\"O\n\x0f\x43oncurrencyLine\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x05\"j\n\x12\x43oncurrencyLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ConcurrencyLine\"E\n\x19WritingInjectedSQLForNode\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"~\n\x1cWritingInjectedSQLForNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.WritingInjectedSQLForNode\"9\n\rNodeCompiling\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"f\n\x10NodeCompilingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeCompiling\"9\n\rNodeExecuting\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"f\n\x10NodeExecutingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeExecuting\"m\n\x10LogHookStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"l\n\x13LogHookStartLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.LogHookStartLine\"\x93\x01\n\x0eLogHookEndLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"h\n\x11LogHookEndLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogHookEndLine\"\x93\x01\n\x0fSkippingDetails\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\"j\n\x12SkippingDetailsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SkippingDetails\"\r\n\x0bNothingToDo\"b\n\x0eNothingToDoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.NothingToDo\",\n\x1dRunningOperationUncaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x86\x01\n RunningOperationUncaughtErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.RunningOperationUncaughtError\"\x93\x01\n\x0c\x45ndRunResult\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.proto_types.RunResultMsg\x12\x14\n\x0c\x65lapsed_time\x18\x02 \x01(\x02\x12\x30\n\x0cgenerated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07success\x18\x04 \x01(\x08\"d\n\x0f\x45ndRunResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.EndRunResult\"\x11\n\x0fNoNodesSelected\"j\n\x12NoNodesSelectedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.NoNodesSelected\"w\n\x10\x43ommandCompleted\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x02\"l\n\x13\x43ommandCompletedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.CommandCompleted\"z\n\x08ShowNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07preview\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12\r\n\x05quiet\x18\x06 \x01(\x08\"\\\n\x0bShowNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.ShowNode\"\x7f\n\x0c\x43ompiledNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiled\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12\r\n\x05quiet\x18\x06 \x01(\x08\"d\n\x0f\x43ompiledNodeMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.CompiledNode\"Y\n\x18SnapshotTimestampWarning\x12\x1f\n\x17snapshot_time_data_type\x18\x01 \x01(\t\x12\x1c\n\x14updated_at_data_type\x18\x02 \x01(\t\"|\n\x1bSnapshotTimestampWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.SnapshotTimestampWarning\"\'\n\x18MicrobatchExecutionDebug\x12\x0b\n\x03msg\x18\x01 \x01(\t\"|\n\x1bMicrobatchExecutionDebugMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.MicrobatchExecutionDebug\"z\n\rLogStartBatch\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_index\x18\x03 \x01(\x05\x12\x15\n\rtotal_batches\x18\x04 \x01(\x05\"f\n\x10LogStartBatchMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogStartBatch\"\xc6\x01\n\x0eLogBatchResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x62\x61tch_index\x18\x04 \x01(\x05\x12\x15\n\rtotal_batches\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12!\n\x05group\x18\x07 \x01(\x0b\x32\x12.proto_types.Group\"h\n\x11LogBatchResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogBatchResult\"b\n\x17\x43\x61tchableExceptionOnRun\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"z\n\x1a\x43\x61tchableExceptionOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.CatchableExceptionOnRun\"_\n\x12InternalErrorOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12(\n\tnode_info\x18\x03 \x01(\x0b\x32\x15.proto_types.NodeInfo\"p\n\x15InternalErrorOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InternalErrorOnRun\"u\n\x15GenericExceptionOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\"v\n\x18GenericExceptionOnRunMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.GenericExceptionOnRun\"N\n\x1aNodeConnectionReleaseError\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x80\x01\n\x1dNodeConnectionReleaseErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.NodeConnectionReleaseError\"\x1f\n\nFoundStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\"`\n\rFoundStatsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.FoundStats\"\x17\n\x15MainKeyboardInterrupt\"v\n\x18MainKeyboardInterruptMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainKeyboardInterrupt\"#\n\x14MainEncounteredError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"t\n\x17MainEncounteredErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MainEncounteredError\"%\n\x0eMainStackTrace\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\"h\n\x11MainStackTraceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainStackTrace\"p\n\x13TimingInfoCollected\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12/\n\x0btiming_info\x18\x02 \x01(\x0b\x32\x1a.proto_types.TimingInfoMsg\"r\n\x16TimingInfoCollectedMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.TimingInfoCollected\"&\n\x12LogDebugStackTrace\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"p\n\x15LogDebugStackTraceMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDebugStackTrace\"\x1e\n\x0e\x43heckCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"h\n\x11\x43heckCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CheckCleanPath\" \n\x10\x43onfirmCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"l\n\x13\x43onfirmCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConfirmCleanPath\"\"\n\x12ProtectedCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"p\n\x15ProtectedCleanPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ProtectedCleanPath\"\x14\n\x12\x46inishedCleanPaths\"p\n\x15\x46inishedCleanPathsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FinishedCleanPaths\"5\n\x0bOpenCommand\x12\x10\n\x08open_cmd\x18\x01 \x01(\t\x12\x14\n\x0cprofiles_dir\x18\x02 \x01(\t\"b\n\x0eOpenCommandMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.OpenCommand\"0\n\x0fServingDocsPort\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"j\n\x12ServingDocsPortMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ServingDocsPort\"%\n\x15ServingDocsAccessInfo\x12\x0c\n\x04port\x18\x01 \x01(\t\"v\n\x18ServingDocsAccessInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ServingDocsAccessInfo\"\x15\n\x13ServingDocsExitInfo\"r\n\x16ServingDocsExitInfoMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.ServingDocsExitInfo\"\x97\x01\n\x10RunResultWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12!\n\x05group\x18\x05 \x01(\x0b\x32\x12.proto_types.Group\"l\n\x13RunResultWarningMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultWarning\"\x97\x01\n\x10RunResultFailure\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12(\n\tnode_info\x18\x04 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12!\n\x05group\x18\x05 \x01(\x0b\x32\x12.proto_types.Group\"l\n\x13RunResultFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultFailure\"k\n\tStatsLine\x12\x30\n\x05stats\x18\x01 \x03(\x0b\x32!.proto_types.StatsLine.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"^\n\x0cStatsLineMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.StatsLine\"j\n\x0eRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12!\n\x05group\x18\x03 \x01(\x0b\x32\x12.proto_types.Group\"h\n\x11RunResultErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RunResultError\"S\n\x17RunResultErrorNoMessage\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1aRunResultErrorNoMessageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultErrorNoMessage\"I\n\x0fSQLCompiledPath\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"j\n\x12SQLCompiledPathMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SQLCompiledPath\"W\n\x14\x43heckNodeTestFailure\x12\x15\n\rrelation_name\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"t\n\x17\x43heckNodeTestFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.CheckNodeTestFailure\"t\n\x0f\x45ndOfRunSummary\x12\x12\n\nnum_errors\x18\x01 \x01(\x05\x12\x14\n\x0cnum_warnings\x18\x02 \x01(\x05\x12\x1a\n\x12keyboard_interrupt\x18\x03 \x01(\x08\x12\x1b\n\x13num_partial_success\x18\x04 \x01(\x05\"j\n\x12\x45ndOfRunSummaryMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.EndOfRunSummary\"g\n\x13MarkSkippedChildren\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12-\n\nrun_result\x18\x03 \x01(\x0b\x32\x19.proto_types.RunResultMsg\"r\n\x16MarkSkippedChildrenMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.MarkSkippedChildren\"e\n\x13LogSkipBecauseError\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x10\n\x08relation\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0e\n\x06status\x18\x05 \x01(\t\"r\n\x16LogSkipBecauseErrorMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.LogSkipBecauseError\"\x14\n\x12\x45nsureGitInstalled\"p\n\x15\x45nsureGitInstalledMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.EnsureGitInstalled\"\x1a\n\x18\x44\x65psCreatingLocalSymlink\"|\n\x1b\x44\x65psCreatingLocalSymlinkMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsCreatingLocalSymlink\"\x19\n\x17\x44\x65psSymlinkNotAvailable\"z\n\x1a\x44\x65psSymlinkNotAvailableMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsSymlinkNotAvailable\"\x11\n\x0f\x44isableTracking\"j\n\x12\x44isableTrackingMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DisableTracking\"\x1e\n\x0cSendingEvent\x12\x0e\n\x06kwargs\x18\x01 \x01(\t\"d\n\x0fSendingEventMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SendingEvent\"\x12\n\x10SendEventFailure\"l\n\x13SendEventFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SendEventFailure\"\r\n\x0b\x46lushEvents\"b\n\x0e\x46lushEventsMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.FlushEvents\"\x14\n\x12\x46lushEventsFailure\"p\n\x15\x46lushEventsFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FlushEventsFailure\"-\n\x19TrackingInitializeFailure\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"~\n\x1cTrackingInitializeFailureMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.TrackingInitializeFailure\"P\n\x17RunResultWarningMessage\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1aRunResultWarningMessageMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultWarningMessage\"\x1a\n\x0b\x44\x65\x62ugCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"b\n\x0e\x44\x65\x62ugCmdOutMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.DebugCmdOut\"\x1d\n\x0e\x44\x65\x62ugCmdResult\x12\x0b\n\x03msg\x18\x01 \x01(\t\"h\n\x11\x44\x65\x62ugCmdResultMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DebugCmdResult\"\x19\n\nListCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"`\n\rListCmdOutMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.ListCmdOut\"\xec\x01\n\x0eResourceReport\x12\x14\n\x0c\x63ommand_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommand_success\x18\x03 \x01(\x08\x12\x1f\n\x17\x63ommand_wall_clock_time\x18\x04 \x01(\x02\x12\x19\n\x11process_user_time\x18\x05 \x01(\x02\x12\x1b\n\x13process_kernel_time\x18\x06 \x01(\x02\x12\x1b\n\x13process_mem_max_rss\x18\x07 \x01(\x03\x12\x19\n\x11process_in_blocks\x18\x08 \x01(\x03\x12\x1a\n\x12process_out_blocks\x18\t \x01(\x03\"h\n\x11ResourceReportMsg\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.proto_types.CoreEventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ResourceReportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COREEVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_MAINREPORTARGS_ARGSENTRY']._loaded_options = None
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_options = b'8\001'
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._loaded_options = None
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_options = b'8\001'
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._loaded_options = None
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_options = b'8\001'
  _globals['_GROUP_OWNERENTRY']._loaded_options = None
  _globals['_GROUP_OWNERENTRY']._serialized_options = b'8\001'
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._loaded_options = None
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_options = b'8\001'
  _globals['_STATSLINE_STATSENTRY']._loaded_options = None
  _globals['_STATSLINE_STATSENTRY']._serialized_options = b'8\001'
  _globals['_COREEVENTINFO']._serialized_start=97
  _globals['_COREEVENTINFO']._serialized_end=378
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_start=334
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_end=378
  _globals['_NODERELATION']._serialized_start=380
  _globals['_NODERELATION']._serialized_end=466
  _globals['_NODEINFO']._serialized_start=469
  _globals['_NODEINFO']._serialized_end=742
  _globals['_TIMINGINFOMSG']._serialized_start=744
  _globals['_TIMINGINFOMSG']._serialized_end=871
  _globals['_RUNRESULTMSG']._serialized_start=874
  _globals['_RUNRESULTMSG']._serialized_end=1083
  _globals['_COLUMNTYPE']._serialized_start=1085
  _globals['_COLUMNTYPE']._serialized_end=1177
  _globals['_COLUMNCONSTRAINT']._serialized_start=1179
  _globals['_COLUMNCONSTRAINT']._serialized_end=1268
  _globals['_MODELCONSTRAINT']._serialized_start=1270
  _globals['_MODELCONSTRAINT']._serialized_end=1354
  _globals['_MAINREPORTVERSION']._serialized_start=1356
  _globals['_MAINREPORTVERSION']._serialized_end=1413
  _globals['_MAINREPORTVERSIONMSG']._serialized_start=1415
  _globals['_MAINREPORTVERSIONMSG']._serialized_end=1525
  _globals['_MAINREPORTARGS']._serialized_start=1527
  _globals['_MAINREPORTARGS']._serialized_end=1641
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_start=1598
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_end=1641
  _globals['_MAINREPORTARGSMSG']._serialized_start=1643
  _globals['_MAINREPORTARGSMSG']._serialized_end=1747
  _globals['_MAINTRACKINGUSERSTATE']._serialized_start=1749
  _globals['_MAINTRACKINGUSERSTATE']._serialized_end=1792
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_start=1794
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_end=1912
  _globals['_MERGEDFROMSTATE']._serialized_start=1914
  _globals['_MERGEDFROMSTATE']._serialized_end=1967
  _globals['_MERGEDFROMSTATEMSG']._serialized_start=1969
  _globals['_MERGEDFROMSTATEMSG']._serialized_end=2075
  _globals['_MISSINGPROFILETARGET']._serialized_start=2077
  _globals['_MISSINGPROFILETARGET']._serialized_end=2142
  _globals['_MISSINGPROFILETARGETMSG']._serialized_start=2144
  _globals['_MISSINGPROFILETARGETMSG']._serialized_end=2260
  _globals['_INVALIDOPTIONYAML']._serialized_start=2262
  _globals['_INVALIDOPTIONYAML']._serialized_end=2302
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_start=2304
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_end=2414
  _globals['_LOGDBTPROJECTERROR']._serialized_start=2416
  _globals['_LOGDBTPROJECTERROR']._serialized_end=2449
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_start=2451
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_end=2563
  _globals['_LOGDBTPROFILEERROR']._serialized_start=2565
  _globals['_LOGDBTPROFILEERROR']._serialized_end=2616
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_start=2618
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_end=2730
  _globals['_STARTERPROJECTPATH']._serialized_start=2732
  _globals['_STARTERPROJECTPATH']._serialized_end=2765
  _globals['_STARTERPROJECTPATHMSG']._serialized_start=2767
  _globals['_STARTERPROJECTPATHMSG']._serialized_end=2879
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_start=2881
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_end=2917
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_start=2919
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_end=3037
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_start=3039
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_end=3078
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_start=3080
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_end=3196
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_start=3198
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_end=3252
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_start=3254
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_end=3378
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_start=3380
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_end=3446
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_start=3449
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_end=3597
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_start=3599
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_end=3666
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_start=3669
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_end=3819
  _globals['_SETTINGUPPROFILE']._serialized_start=3821
  _globals['_SETTINGUPPROFILE']._serialized_end=3839
  _globals['_SETTINGUPPROFILEMSG']._serialized_start=3841
  _globals['_SETTINGUPPROFILEMSG']._serialized_end=3949
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_start=3951
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_end=3979
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_start=3982
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_end=4110
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_start=4112
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_end=4152
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_start=4154
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_end=4278
  _globals['_PROJECTCREATED']._serialized_start=4280
  _globals['_PROJECTCREATED']._serialized_end=4355
  _globals['_PROJECTCREATEDMSG']._serialized_start=4357
  _globals['_PROJECTCREATEDMSG']._serialized_end=4461
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_start=4463
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_end=4527
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_start=4530
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_end=4658
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_start=4660
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_end=4691
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_start=4694
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_end=4828
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_start=4830
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_end=4902
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_start=4905
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_end=5035
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_start=5037
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_end=5107
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_start=5109
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_end=5235
  _globals['_METRICATTRIBUTESRENAMED']._serialized_start=5237
  _globals['_METRICATTRIBUTESRENAMED']._serialized_end=5283
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_start=5285
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_end=5407
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_start=5409
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_end=5452
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_start=5454
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_end=5576
  _globals['_INTERNALDEPRECATION']._serialized_start=5578
  _globals['_INTERNALDEPRECATION']._serialized_end=5672
  _globals['_INTERNALDEPRECATIONMSG']._serialized_start=5674
  _globals['_INTERNALDEPRECATIONMSG']._serialized_end=5788
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_start=5790
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_end=5854
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_start=5857
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_end=5985
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_start=5987
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_end=6038
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_start=6040
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_end=6164
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_start=6166
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_end=6220
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_start=6223
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_end=6353
  _globals['_TESTSCONFIGDEPRECATION']._serialized_start=6355
  _globals['_TESTSCONFIGDEPRECATION']._serialized_end=6422
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_start=6424
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_end=6544
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_start=6546
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_end=6576
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_start=6579
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_end=6711
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_start=6713
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_end=6780
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_start=6783
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_end=6921
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_start=6923
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_end=7028
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_start=7031
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_end=7175
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_start=7177
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_end=7272
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_start=7275
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_end=7433
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_start=7435
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_end=7470
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_start=7473
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_end=7615
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATION']._serialized_start=7617
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATION']._serialized_end=7665
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATIONMSG']._serialized_start=7668
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATIONMSG']._serialized_end=7836
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATION']._serialized_start=7838
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATION']._serialized_end=7873
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATIONMSG']._serialized_start=7876
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATIONMSG']._serialized_end=8018
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATION']._serialized_start=8020
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATION']._serialized_end=8064
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATIONMSG']._serialized_start=8067
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATIONMSG']._serialized_end=8227
  _globals['_DEPRECATEDMODEL']._serialized_start=8229
  _globals['_DEPRECATEDMODEL']._serialized_end=8315
  _globals['_DEPRECATEDMODELMSG']._serialized_start=8317
  _globals['_DEPRECATEDMODELMSG']._serialized_end=8423
  _globals['_INPUTFILEDIFFERROR']._serialized_start=8425
  _globals['_INPUTFILEDIFFERROR']._serialized_end=8480
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_start=8482
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_end=8594
  _globals['_INVALIDVALUEFORFIELD']._serialized_start=8596
  _globals['_INVALIDVALUEFORFIELD']._serialized_end=8659
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_start=8661
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_end=8777
  _globals['_VALIDATIONWARNING']._serialized_start=8779
  _globals['_VALIDATIONWARNING']._serialized_end=8860
  _globals['_VALIDATIONWARNINGMSG']._serialized_start=8862
  _globals['_VALIDATIONWARNINGMSG']._serialized_end=8972
  _globals['_PARSEPERFINFOPATH']._serialized_start=8974
  _globals['_PARSEPERFINFOPATH']._serialized_end=9007
  _globals['_PARSEPERFINFOPATHMSG']._serialized_start=9009
  _globals['_PARSEPERFINFOPATHMSG']._serialized_end=9119
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_start=9121
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_end=9170
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_start=9173
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_end=9315
  _globals['_PARTIALPARSINGERROR']._serialized_start=9318
  _globals['_PARTIALPARSINGERROR']._serialized_end=9452
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_start=9406
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_end=9452
  _globals['_PARTIALPARSINGERRORMSG']._serialized_start=9454
  _globals['_PARTIALPARSINGERRORMSG']._serialized_end=9568
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_start=9570
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_end=9597
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_start=9599
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_end=9725
  _globals['_UNABLETOPARTIALPARSE']._serialized_start=9727
  _globals['_UNABLETOPARTIALPARSE']._serialized_end=9765
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_start=9767
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_end=9883
  _globals['_STATECHECKVARSHASH']._serialized_start=9885
  _globals['_STATECHECKVARSHASH']._serialized_end=9987
  _globals['_STATECHECKVARSHASHMSG']._serialized_start=9989
  _globals['_STATECHECKVARSHASHMSG']._serialized_end=10101
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_start=10103
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_end=10129
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_start=10131
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_end=10255
  _globals['_PARSEDFILELOADFAILED']._serialized_start=10257
  _globals['_PARSEDFILELOADFAILED']._serialized_end=10324
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_start=10326
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_end=10442
  _globals['_PARTIALPARSINGENABLED']._serialized_start=10444
  _globals['_PARTIALPARSINGENABLED']._serialized_end=10516
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_start=10518
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_end=10636
  _globals['_PARTIALPARSINGFILE']._serialized_start=10638
  _globals['_PARTIALPARSINGFILE']._serialized_end=10694
  _globals['_PARTIALPARSINGFILEMSG']._serialized_start=10696
  _globals['_PARTIALPARSINGFILEMSG']._serialized_end=10808
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_start=10811
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_end=10986
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_start=10989
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_end=11127
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_start=11129
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_end=11184
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_start=11186
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_end=11310
  _globals['_SEEDINCREASED']._serialized_start=11312
  _globals['_SEEDINCREASED']._serialized_end=11363
  _globals['_SEEDINCREASEDMSG']._serialized_start=11365
  _globals['_SEEDINCREASEDMSG']._serialized_end=11467
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_start=11469
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_end=11531
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_start=11533
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_end=11657
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_start=11659
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_end=11727
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_start=11730
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_end=11866
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_start=11868
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_end=11960
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_start=11963
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_end=12101
  _globals['_UNUSEDTABLES']._serialized_start=12103
  _globals['_UNUSEDTABLES']._serialized_end=12140
  _globals['_UNUSEDTABLESMSG']._serialized_start=12142
  _globals['_UNUSEDTABLESMSG']._serialized_end=12242
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_start=12245
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_end=12380
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_start=12382
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_end=12504
  _globals['_NONODEFORYAMLKEY']._serialized_start=12506
  _globals['_NONODEFORYAMLKEY']._serialized_end=12581
  _globals['_NONODEFORYAMLKEYMSG']._serialized_start=12583
  _globals['_NONODEFORYAMLKEYMSG']._serialized_end=12691
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_start=12693
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_end=12736
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_start=12738
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_end=12856
  _globals['_NODENOTFOUNDORDISABLED']._serialized_start=12859
  _globals['_NODENOTFOUNDORDISABLED']._serialized_end=13043
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_start=13045
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_end=13165
  _globals['_JINJALOGWARNING']._serialized_start=13167
  _globals['_JINJALOGWARNING']._serialized_end=13239
  _globals['_JINJALOGWARNINGMSG']._serialized_start=13241
  _globals['_JINJALOGWARNINGMSG']._serialized_end=13347
  _globals['_JINJALOGINFO']._serialized_start=13349
  _globals['_JINJALOGINFO']._serialized_end=13418
  _globals['_JINJALOGINFOMSG']._serialized_start=13420
  _globals['_JINJALOGINFOMSG']._serialized_end=13520
  _globals['_JINJALOGDEBUG']._serialized_start=13522
  _globals['_JINJALOGDEBUG']._serialized_end=13592
  _globals['_JINJALOGDEBUGMSG']._serialized_start=13594
  _globals['_JINJALOGDEBUGMSG']._serialized_end=13696
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_start=13699
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_end=13873
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_start=13876
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_end=14012
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_start=14015
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_end=14213
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_start=14216
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_end=14348
  _globals['_DEPRECATEDREFERENCE']._serialized_start=14351
  _globals['_DEPRECATEDREFERENCE']._serialized_end=14540
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_start=14542
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_end=14656
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_start=14658
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_end=14718
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_start=14721
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_end=14869
  _globals['_PARSEINLINENODEERROR']._serialized_start=14871
  _globals['_PARSEINLINENODEERROR']._serialized_end=14948
  _globals['_PARSEINLINENODEERRORMSG']._serialized_start=14950
  _globals['_PARSEINLINENODEERRORMSG']._serialized_end=15066
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_start=15068
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_end=15108
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_start=15110
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_end=15236
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_start=15239
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_end=15633
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_start=15635
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_end=15761
  _globals['_WARNSTATETARGETEQUAL']._serialized_start=15763
  _globals['_WARNSTATETARGETEQUAL']._serialized_end=15805
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_start=15807
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_end=15923
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_start=15925
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_end=15962
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_start=15964
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_end=16084
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTS']._serialized_start=16086
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTS']._serialized_end=16140
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTSMSG']._serialized_start=16143
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTSMSG']._serialized_end=16283
  _globals['_INVALIDCONCURRENTBATCHESCONFIG']._serialized_start=16285
  _globals['_INVALIDCONCURRENTBATCHESCONFIG']._serialized_end=16359
  _globals['_INVALIDCONCURRENTBATCHESCONFIGMSG']._serialized_start=16362
  _globals['_INVALIDCONCURRENTBATCHESCONFIGMSG']._serialized_end=16498
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_start=16500
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_end=16547
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_start=16550
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_end=16684
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_start=16686
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_end=16733
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_start=16736
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_end=16866
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_start=16868
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_end=16920
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_start=16923
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_end=17073
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_start=17075
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_end=17121
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_start=17124
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_end=17262
  _globals['_GITNOTHINGTODO']._serialized_start=17264
  _globals['_GITNOTHINGTODO']._serialized_end=17293
  _globals['_GITNOTHINGTODOMSG']._serialized_start=17295
  _globals['_GITNOTHINGTODOMSG']._serialized_end=17399
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_start=17401
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_end=17470
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_start=17473
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_end=17611
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_start=17613
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_end=17655
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_start=17657
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_end=17779
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_start=17781
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_end=17822
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_start=17825
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_end=17953
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_start=17955
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_end=18016
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_start=18019
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_end=18149
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_start=18151
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_end=18246
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_start=18249
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_end=18383
  _globals['_DEPSNOPACKAGESFOUND']._serialized_start=18385
  _globals['_DEPSNOPACKAGESFOUND']._serialized_end=18406
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_start=18408
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_end=18522
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_start=18524
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_end=18571
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_start=18573
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_end=18695
  _globals['_DEPSINSTALLINFO']._serialized_start=18697
  _globals['_DEPSINSTALLINFO']._serialized_end=18736
  _globals['_DEPSINSTALLINFOMSG']._serialized_start=18738
  _globals['_DEPSINSTALLINFOMSG']._serialized_end=18844
  _globals['_DEPSUPDATEAVAILABLE']._serialized_start=18846
  _globals['_DEPSUPDATEAVAILABLE']._serialized_end=18891
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_start=18893
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_end=19007
  _globals['_DEPSUPTODATE']._serialized_start=19009
  _globals['_DEPSUPTODATE']._serialized_end=19023
  _globals['_DEPSUPTODATEMSG']._serialized_start=19025
  _globals['_DEPSUPTODATEMSG']._serialized_end=19125
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_start=19127
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_end=19171
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_start=19173
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_end=19289
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_start=19291
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_end=19337
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_start=19340
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_end=19468
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_start=19470
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_end=19516
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_start=19519
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_end=19657
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_start=19659
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_end=19725
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_start=19728
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_end=19868
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_start=19870
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_end=19920
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_start=19923
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_end=20059
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_start=20061
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_end=20111
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_start=20114
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_end=20250
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_start=20252
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_end=20305
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_start=20308
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_end=20450
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_start=20452
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_end=20503
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_start=20506
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_end=20644
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_start=20646
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_end=20686
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_start=20688
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_end=20812
  _globals['_DEPSUNPINNED']._serialized_start=20814
  _globals['_DEPSUNPINNED']._serialized_end=20859
  _globals['_DEPSUNPINNEDMSG']._serialized_start=20861
  _globals['_DEPSUNPINNEDMSG']._serialized_end=20961
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_start=20963
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_end=21010
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_start=21013
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_end=21143
  _globals['_DEPSLOCKUPDATING']._serialized_start=21145
  _globals['_DEPSLOCKUPDATING']._serialized_end=21186
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_start=21188
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_end=21296
  _globals['_DEPSADDPACKAGE']._serialized_start=21298
  _globals['_DEPSADDPACKAGE']._serialized_end=21380
  _globals['_DEPSADDPACKAGEMSG']._serialized_start=21382
  _globals['_DEPSADDPACKAGEMSG']._serialized_end=21486
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_start=21489
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_end=21656
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_start=21603
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_end=21656
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_start=21658
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_end=21784
  _globals['_DEPSVERSIONMISSING']._serialized_start=21786
  _globals['_DEPSVERSIONMISSING']._serialized_end=21822
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_start=21824
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_end=21936
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_start=21938
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_end=21985
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_start=21987
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_end=22109
  _globals['_ARTIFACTWRITTEN']._serialized_start=22111
  _globals['_ARTIFACTWRITTEN']._serialized_end=22174
  _globals['_ARTIFACTWRITTENMSG']._serialized_start=22176
  _globals['_ARTIFACTWRITTENMSG']._serialized_end=22282
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_start=22284
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_end=22326
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_start=22329
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_end=22459
  _globals['_COMPILECOMPLETE']._serialized_start=22461
  _globals['_COMPILECOMPLETE']._serialized_end=22478
  _globals['_COMPILECOMPLETEMSG']._serialized_start=22480
  _globals['_COMPILECOMPLETEMSG']._serialized_end=22586
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_start=22588
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_end=22612
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_start=22614
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_end=22734
  _globals['_SEEDHEADER']._serialized_start=22736
  _globals['_SEEDHEADER']._serialized_end=22764
  _globals['_SEEDHEADERMSG']._serialized_start=22766
  _globals['_SEEDHEADERMSG']._serialized_end=22862
  _globals['_SQLRUNNEREXCEPTION']._serialized_start=22864
  _globals['_SQLRUNNEREXCEPTION']._serialized_end=22957
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_start=22959
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_end=23071
  _globals['_GROUP']._serialized_start=23074
  _globals['_GROUP']._serialized_end=23209
  _globals['_GROUP_OWNERENTRY']._serialized_start=23165
  _globals['_GROUP_OWNERENTRY']._serialized_end=23209
  _globals['_LOGTESTRESULT']._serialized_start=23212
  _globals['_LOGTESTRESULT']._serialized_end=23438
  _globals['_LOGTESTRESULTMSG']._serialized_start=23440
  _globals['_LOGTESTRESULTMSG']._serialized_end=23542
  _globals['_LOGSTARTLINE']._serialized_start=23544
  _globals['_LOGSTARTLINE']._serialized_end=23651
  _globals['_LOGSTARTLINEMSG']._serialized_start=23653
  _globals['_LOGSTARTLINEMSG']._serialized_end=23753
  _globals['_LOGMODELRESULT']._serialized_start=23756
  _globals['_LOGMODELRESULT']._serialized_end=23940
  _globals['_LOGMODELRESULTMSG']._serialized_start=23942
  _globals['_LOGMODELRESULTMSG']._serialized_end=24046
  _globals['_LOGSNAPSHOTRESULT']._serialized_start=24049
  _globals['_LOGSNAPSHOTRESULT']._serialized_end=24323
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_start=24281
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_end=24323
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_start=24325
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_end=24435
  _globals['_LOGSEEDRESULT']._serialized_start=24438
  _globals['_LOGSEEDRESULT']._serialized_end=24623
  _globals['_LOGSEEDRESULTMSG']._serialized_start=24625
  _globals['_LOGSEEDRESULTMSG']._serialized_end=24727
  _globals['_LOGFRESHNESSRESULT']._serialized_start=24730
  _globals['_LOGFRESHNESSRESULT']._serialized_end=24903
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_start=24905
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_end=25017
  _globals['_LOGNODENOOPRESULT']._serialized_start=25020
  _globals['_LOGNODENOOPRESULT']._serialized_end=25172
  _globals['_LOGNODENOOPRESULTMSG']._serialized_start=25174
  _globals['_LOGNODENOOPRESULTMSG']._serialized_end=25284
  _globals['_LOGCANCELLINE']._serialized_start=25286
  _globals['_LOGCANCELLINE']._serialized_end=25320
  _globals['_LOGCANCELLINEMSG']._serialized_start=25322
  _globals['_LOGCANCELLINEMSG']._serialized_end=25424
  _globals['_DEFAULTSELECTOR']._serialized_start=25426
  _globals['_DEFAULTSELECTOR']._serialized_end=25457
  _globals['_DEFAULTSELECTORMSG']._serialized_start=25459
  _globals['_DEFAULTSELECTORMSG']._serialized_end=25565
  _globals['_NODESTART']._serialized_start=25567
  _globals['_NODESTART']._serialized_end=25620
  _globals['_NODESTARTMSG']._serialized_start=25622
  _globals['_NODESTARTMSG']._serialized_end=25716
  _globals['_NODEFINISHED']._serialized_start=25718
  _globals['_NODEFINISHED']._serialized_end=25821
  _globals['_NODEFINISHEDMSG']._serialized_start=25823
  _globals['_NODEFINISHEDMSG']._serialized_end=25923
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_start=25925
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_end=25968
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_start=25971
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_end=26101
  _globals['_CONCURRENCYLINE']._serialized_start=26103
  _globals['_CONCURRENCYLINE']._serialized_end=26182
  _globals['_CONCURRENCYLINEMSG']._serialized_start=26184
  _globals['_CONCURRENCYLINEMSG']._serialized_end=26290
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_start=26292
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_end=26361
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_start=26363
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_end=26489
  _globals['_NODECOMPILING']._serialized_start=26491
  _globals['_NODECOMPILING']._serialized_end=26548
  _globals['_NODECOMPILINGMSG']._serialized_start=26550
  _globals['_NODECOMPILINGMSG']._serialized_end=26652
  _globals['_NODEEXECUTING']._serialized_start=26654
  _globals['_NODEEXECUTING']._serialized_end=26711
  _globals['_NODEEXECUTINGMSG']._serialized_start=26713
  _globals['_NODEEXECUTINGMSG']._serialized_end=26815
  _globals['_LOGHOOKSTARTLINE']._serialized_start=26817
  _globals['_LOGHOOKSTARTLINE']._serialized_end=26926
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_start=26928
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_end=27036
  _globals['_LOGHOOKENDLINE']._serialized_start=27039
  _globals['_LOGHOOKENDLINE']._serialized_end=27186
  _globals['_LOGHOOKENDLINEMSG']._serialized_start=27188
  _globals['_LOGHOOKENDLINEMSG']._serialized_end=27292
  _globals['_SKIPPINGDETAILS']._serialized_start=27295
  _globals['_SKIPPINGDETAILS']._serialized_end=27442
  _globals['_SKIPPINGDETAILSMSG']._serialized_start=27444
  _globals['_SKIPPINGDETAILSMSG']._serialized_end=27550
  _globals['_NOTHINGTODO']._serialized_start=27552
  _globals['_NOTHINGTODO']._serialized_end=27565
  _globals['_NOTHINGTODOMSG']._serialized_start=27567
  _globals['_NOTHINGTODOMSG']._serialized_end=27665
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_start=27667
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_end=27711
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_start=27714
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_end=27848
  _globals['_ENDRUNRESULT']._serialized_start=27851
  _globals['_ENDRUNRESULT']._serialized_end=27998
  _globals['_ENDRUNRESULTMSG']._serialized_start=28000
  _globals['_ENDRUNRESULTMSG']._serialized_end=28100
  _globals['_NONODESSELECTED']._serialized_start=28102
  _globals['_NONODESSELECTED']._serialized_end=28119
  _globals['_NONODESSELECTEDMSG']._serialized_start=28121
  _globals['_NONODESSELECTEDMSG']._serialized_end=28227
  _globals['_COMMANDCOMPLETED']._serialized_start=28229
  _globals['_COMMANDCOMPLETED']._serialized_end=28348
  _globals['_COMMANDCOMPLETEDMSG']._serialized_start=28350
  _globals['_COMMANDCOMPLETEDMSG']._serialized_end=28458
  _globals['_SHOWNODE']._serialized_start=28460
  _globals['_SHOWNODE']._serialized_end=28582
  _globals['_SHOWNODEMSG']._serialized_start=28584
  _globals['_SHOWNODEMSG']._serialized_end=28676
  _globals['_COMPILEDNODE']._serialized_start=28678
  _globals['_COMPILEDNODE']._serialized_end=28805
  _globals['_COMPILEDNODEMSG']._serialized_start=28807
  _globals['_COMPILEDNODEMSG']._serialized_end=28907
  _globals['_SNAPSHOTTIMESTAMPWARNING']._serialized_start=28909
  _globals['_SNAPSHOTTIMESTAMPWARNING']._serialized_end=28998
  _globals['_SNAPSHOTTIMESTAMPWARNINGMSG']._serialized_start=29000
  _globals['_SNAPSHOTTIMESTAMPWARNINGMSG']._serialized_end=29124
  _globals['_MICROBATCHEXECUTIONDEBUG']._serialized_start=29126
  _globals['_MICROBATCHEXECUTIONDEBUG']._serialized_end=29165
  _globals['_MICROBATCHEXECUTIONDEBUGMSG']._serialized_start=29167
  _globals['_MICROBATCHEXECUTIONDEBUGMSG']._serialized_end=29291
  _globals['_LOGSTARTBATCH']._serialized_start=29293
  _globals['_LOGSTARTBATCH']._serialized_end=29415
  _globals['_LOGSTARTBATCHMSG']._serialized_start=29417
  _globals['_LOGSTARTBATCHMSG']._serialized_end=29519
  _globals['_LOGBATCHRESULT']._serialized_start=29522
  _globals['_LOGBATCHRESULT']._serialized_end=29720
  _globals['_LOGBATCHRESULTMSG']._serialized_start=29722
  _globals['_LOGBATCHRESULTMSG']._serialized_end=29826
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_start=29828
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_end=29926
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_start=29928
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_end=30050
  _globals['_INTERNALERRORONRUN']._serialized_start=30052
  _globals['_INTERNALERRORONRUN']._serialized_end=30147
  _globals['_INTERNALERRORONRUNMSG']._serialized_start=30149
  _globals['_INTERNALERRORONRUNMSG']._serialized_end=30261
  _globals['_GENERICEXCEPTIONONRUN']._serialized_start=30263
  _globals['_GENERICEXCEPTIONONRUN']._serialized_end=30380
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_start=30382
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_end=30500
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_start=30502
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_end=30580
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_start=30583
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_end=30711
  _globals['_FOUNDSTATS']._serialized_start=30713
  _globals['_FOUNDSTATS']._serialized_end=30744
  _globals['_FOUNDSTATSMSG']._serialized_start=30746
  _globals['_FOUNDSTATSMSG']._serialized_end=30842
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_start=30844
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_end=30867
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_start=30869
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_end=30987
  _globals['_MAINENCOUNTEREDERROR']._serialized_start=30989
  _globals['_MAINENCOUNTEREDERROR']._serialized_end=31024
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_start=31026
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_end=31142
  _globals['_MAINSTACKTRACE']._serialized_start=31144
  _globals['_MAINSTACKTRACE']._serialized_end=31181
  _globals['_MAINSTACKTRACEMSG']._serialized_start=31183
  _globals['_MAINSTACKTRACEMSG']._serialized_end=31287
  _globals['_TIMINGINFOCOLLECTED']._serialized_start=31289
  _globals['_TIMINGINFOCOLLECTED']._serialized_end=31401
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_start=31403
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_end=31517
  _globals['_LOGDEBUGSTACKTRACE']._serialized_start=31519
  _globals['_LOGDEBUGSTACKTRACE']._serialized_end=31557
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_start=31559
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_end=31671
  _globals['_CHECKCLEANPATH']._serialized_start=31673
  _globals['_CHECKCLEANPATH']._serialized_end=31703
  _globals['_CHECKCLEANPATHMSG']._serialized_start=31705
  _globals['_CHECKCLEANPATHMSG']._serialized_end=31809
  _globals['_CONFIRMCLEANPATH']._serialized_start=31811
  _globals['_CONFIRMCLEANPATH']._serialized_end=31843
  _globals['_CONFIRMCLEANPATHMSG']._serialized_start=31845
  _globals['_CONFIRMCLEANPATHMSG']._serialized_end=31953
  _globals['_PROTECTEDCLEANPATH']._serialized_start=31955
  _globals['_PROTECTEDCLEANPATH']._serialized_end=31989
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_start=31991
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_end=32103
  _globals['_FINISHEDCLEANPATHS']._serialized_start=32105
  _globals['_FINISHEDCLEANPATHS']._serialized_end=32125
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_start=32127
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_end=32239
  _globals['_OPENCOMMAND']._serialized_start=32241
  _globals['_OPENCOMMAND']._serialized_end=32294
  _globals['_OPENCOMMANDMSG']._serialized_start=32296
  _globals['_OPENCOMMANDMSG']._serialized_end=32394
  _globals['_SERVINGDOCSPORT']._serialized_start=32396
  _globals['_SERVINGDOCSPORT']._serialized_end=32444
  _globals['_SERVINGDOCSPORTMSG']._serialized_start=32446
  _globals['_SERVINGDOCSPORTMSG']._serialized_end=32552
  _globals['_SERVINGDOCSACCESSINFO']._serialized_start=32554
  _globals['_SERVINGDOCSACCESSINFO']._serialized_end=32591
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_start=32593
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_end=32711
  _globals['_SERVINGDOCSEXITINFO']._serialized_start=32713
  _globals['_SERVINGDOCSEXITINFO']._serialized_end=32734
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_start=32736
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_end=32850
  _globals['_RUNRESULTWARNING']._serialized_start=32853
  _globals['_RUNRESULTWARNING']._serialized_end=33004
  _globals['_RUNRESULTWARNINGMSG']._serialized_start=33006
  _globals['_RUNRESULTWARNINGMSG']._serialized_end=33114
  _globals['_RUNRESULTFAILURE']._serialized_start=33117
  _globals['_RUNRESULTFAILURE']._serialized_end=33268
  _globals['_RUNRESULTFAILUREMSG']._serialized_start=33270
  _globals['_RUNRESULTFAILUREMSG']._serialized_end=33378
  _globals['_STATSLINE']._serialized_start=33380
  _globals['_STATSLINE']._serialized_end=33487
  _globals['_STATSLINE_STATSENTRY']._serialized_start=33443
  _globals['_STATSLINE_STATSENTRY']._serialized_end=33487
  _globals['_STATSLINEMSG']._serialized_start=33489
  _globals['_STATSLINEMSG']._serialized_end=33583
  _globals['_RUNRESULTERROR']._serialized_start=33585
  _globals['_RUNRESULTERROR']._serialized_end=33691
  _globals['_RUNRESULTERRORMSG']._serialized_start=33693
  _globals['_RUNRESULTERRORMSG']._serialized_end=33797
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_start=33799
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_end=33882
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_start=33884
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_end=34006
  _globals['_SQLCOMPILEDPATH']._serialized_start=34008
  _globals['_SQLCOMPILEDPATH']._serialized_end=34081
  _globals['_SQLCOMPILEDPATHMSG']._serialized_start=34083
  _globals['_SQLCOMPILEDPATHMSG']._serialized_end=34189
  _globals['_CHECKNODETESTFAILURE']._serialized_start=34191
  _globals['_CHECKNODETESTFAILURE']._serialized_end=34278
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_start=34280
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_end=34396
  _globals['_ENDOFRUNSUMMARY']._serialized_start=34398
  _globals['_ENDOFRUNSUMMARY']._serialized_end=34514
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_start=34516
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_end=34622
  _globals['_MARKSKIPPEDCHILDREN']._serialized_start=34624
  _globals['_MARKSKIPPEDCHILDREN']._serialized_end=34727
  _globals['_MARKSKIPPEDCHILDRENMSG']._serialized_start=34729
  _globals['_MARKSKIPPEDCHILDRENMSG']._serialized_end=34843
  _globals['_LOGSKIPBECAUSEERROR']._serialized_start=34845
  _globals['_LOGSKIPBECAUSEERROR']._serialized_end=34946
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_start=34948
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_end=35062
  _globals['_ENSUREGITINSTALLED']._serialized_start=35064
  _globals['_ENSUREGITINSTALLED']._serialized_end=35084
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_start=35086
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_end=35198
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_start=35200
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_end=35226
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_start=35228
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_end=35352
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_start=35354
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_end=35379
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_start=35381
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_end=35503
  _globals['_DISABLETRACKING']._serialized_start=35505
  _globals['_DISABLETRACKING']._serialized_end=35522
  _globals['_DISABLETRACKINGMSG']._serialized_start=35524
  _globals['_DISABLETRACKINGMSG']._serialized_end=35630
  _globals['_SENDINGEVENT']._serialized_start=35632
  _globals['_SENDINGEVENT']._serialized_end=35662
  _globals['_SENDINGEVENTMSG']._serialized_start=35664
  _globals['_SENDINGEVENTMSG']._serialized_end=35764
  _globals['_SENDEVENTFAILURE']._serialized_start=35766
  _globals['_SENDEVENTFAILURE']._serialized_end=35784
  _globals['_SENDEVENTFAILUREMSG']._serialized_start=35786
  _globals['_SENDEVENTFAILUREMSG']._serialized_end=35894
  _globals['_FLUSHEVENTS']._serialized_start=35896
  _globals['_FLUSHEVENTS']._serialized_end=35909
  _globals['_FLUSHEVENTSMSG']._serialized_start=35911
  _globals['_FLUSHEVENTSMSG']._serialized_end=36009
  _globals['_FLUSHEVENTSFAILURE']._serialized_start=36011
  _globals['_FLUSHEVENTSFAILURE']._serialized_end=36031
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_start=36033
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_end=36145
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_start=36147
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_end=36192
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_start=36194
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_end=36320
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_start=36322
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_end=36402
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_start=36404
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_end=36526
  _globals['_DEBUGCMDOUT']._serialized_start=36528
  _globals['_DEBUGCMDOUT']._serialized_end=36554
  _globals['_DEBUGCMDOUTMSG']._serialized_start=36556
  _globals['_DEBUGCMDOUTMSG']._serialized_end=36654
  _globals['_DEBUGCMDRESULT']._serialized_start=36656
  _globals['_DEBUGCMDRESULT']._serialized_end=36685
  _globals['_DEBUGCMDRESULTMSG']._serialized_start=36687
  _globals['_DEBUGCMDRESULTMSG']._serialized_end=36791
  _globals['_LISTCMDOUT']._serialized_start=36793
  _globals['_LISTCMDOUT']._serialized_end=36818
  _globals['_LISTCMDOUTMSG']._serialized_start=36820
  _globals['_LISTCMDOUTMSG']._serialized_end=36916
  _globals['_RESOURCEREPORT']._serialized_start=36919
  _globals['_RESOURCEREPORT']._serialized_end=37155
  _globals['_RESOURCEREPORTMSG']._serialized_start=37157
  _globals['_RESOURCEREPORTMSG']._serialized_end=37261
# @@protoc_insertion_point(module_scope)
